#!/bin/bash

# Copyright 2007 Chuck Houpt. All rights reserved.

set -eux

if [ "$CONFIGURATION" == 'Release' ]
then

APPCAST_URL=$(xsltproc -stringparam key SUFeedURL infoval.xsl Info.plist)
APPCAST_FILENAME=$(basename $APPCAST_URL)
APPCAST="$TARGET_BUILD_DIR"/"$APPCAST_FILENAME"
IMAGE_FILENAME="$TARGET_NAME"_"$CURRENT_PROJECT_VERSION".zip
ENC_URL=$(dirname "$APPCAST_URL")/"$IMAGE_FILENAME"
ENC_LENGTH=$(stat -f '%z' "$TARGET_BUILD_DIR"/"$IMAGE_FILENAME")
NOTES="ReleaseNotes_$CURRENT_PROJECT_VERSION.html"

DATE=$(date '+%d %b %Y %T %z')

# From: http://www.entropy.ch/blog/Developer/2008/09/22/Sparkle-Appcast-Automation-in-Xcode.html
KEYCHAIN_PRIVKEY_NAME="habilis_sparkle_dsa_priv.pem"
SIGNATURE=$(
	openssl dgst -sha1 -binary < "$TARGET_BUILD_DIR"/"$IMAGE_FILENAME" \
	| openssl dgst -dss1 -sign \
		<(security find-generic-password -g -s "$KEYCHAIN_PRIVKEY_NAME" 2>&1 1>/dev/null \
		 | perl -pe '($_) = /"(.+)"/; s/\\012/\n/g' \
		 | xsltproc -stringparam key NOTE infoval.xsl -) \
	| openssl enc -base64
)

[ $SIGNATURE ] || { echo Unable to load signing private key with name "'$KEYCHAIN_PRIVKEY_NAME'" from keychain; false; }


rm -f "$APPCAST"

if [ -f "$NOTES" ]
then

DESCRIPTION=$(cat "$NOTES")

cat > "$APPCAST" <<END
<?xml version="1.0" encoding="utf-8"?>
<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:sparkle="http://www.andymatuschak.org/xml-namespaces/sparkle">
	<channel>
		<title>$WRAPPER_NAME Appcast</title>
		<link>$APPCAST_URL</link>
		<description>$TARGET_NAME releases.</description>
		<language>en</language>
		<item>
			<title>Version $CURRENT_PROJECT_VERSION</title>
			<sparkle:minimumSystemVersion>10.7</sparkle:minimumSystemVersion>
			<pubDate>$DATE</pubDate>
			<enclosure
				url="$ENC_URL"
				sparkle:version="$CURRENT_PROJECT_VERSION"
				type="application/octet-stream"
				length="$ENC_LENGTH"
				sparkle:dsaSignature="$SIGNATURE"
			/>
			<description><![CDATA[
$DESCRIPTION
			]]></description>
        </item>
    </channel>
</rss>
END

fi
fi

